@@ -1,7 +1,9 @@
 setClass("FunctionDefinition", representation(id = "character", name = "character", math = "expression"), 
   contains = "SBase") 
 
- 
+setMethod("describe", "FunctionDefinition",
+          function(object) paste(id(object), "<-", math(object)))
+
 setMethod("id", "FunctionDefinition", function(object) object@id)
 
  
@@ -22,7 +24,7 @@ setReplaceMethod("name", "FunctionDefinition", function(object, value) {
 })
 
 setReplaceMethod("math", "FunctionDefinition", function(object, value) {
-  object@math <- as.expression(value)
+  object@math <- asMath(value)
   object
 })
 
